---
title: <span class="badge builder"></span> Constraint
---
# <span class="badge builder"></span> Constraint

## Constructor

```python
Constraint()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> canvas.Constraint
```

### <span class="badge object-method"></span> horizontal

```python
def horizontal(horizontal: canvas.HorizontalConstraint) -> typing.Self
```

### <span class="badge object-method"></span> vertical

```python
def vertical(vertical: canvas.VerticalConstraint) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [Constraint](./object-Constraint.md)
